/*********************************************************************/
/*                                                                   */
/* BuildBVCards                                                      */
/*                                                                   */
/* Takes a translatable file (here called "cards") and creates the   */
/* files as required by Visual BLDVIEWS (BVCards.dat) and RODM       */
/* Collection Manager (flcvcard).                                    */
/*                                                                   */
/* Note that the file, "classnames.txt," adds the class support for  */
/* VBV.  In order to retrieve the list of classes in a running RODM, */
/* an exec named GETCLASS is appended to this exec; it can be        */
/* uploaded to the host and run to retrieve a new set of classes as  */
/* required by BuildBVCards.                                         */
/*                                                                   */
/*********************************************************************/
InputFile = "cards.txt"
ClassFile = "classnames.txt"
Output1File = "BVCards.dat"
Output2File = "flcvcard"

"erase "Output1File
"erase "Output2File

Call ReadCommonParms;
Call ReadPackages;

Do while (lines(InputFile))
  line = linein(InputFile)
  start = left(line,2)
  onlytag = left(line,5)
  Select
    When line = '#Wildcard#' Then
    Do
      rc = lineout(Output1File,'[Description]')
      rc = lineout(Output1File,'Wildcard Control')
      rc = lineout(Output1File,'[Object Type]')
      rc = lineout(Output1File,'Control')
      rc = lineout(Output1File,'[AggChild type]')
      rc = lineout(Output1File,'N/A')
      Call EmitSingle('Wildcard')
    End
    When line = '#Annotation#' Then
      Call EmitSingle('Annotation')
    When line = '#ExceptionViewName#' Then
      Call EmitSingle('ExceptionViewName')
    When line = '#DSF#' Then
      Call EmitSingle('DSF')
    When line = '#MF#' Then
      Call EmitSingle('MF')
    When line = '#SAPF#' Then
      Call EmitSingle('SAPF')
    When line = '#TIF#' Then
      Call EmitSingle('TIF')
    When line = '#AIPF#' Then
      Call EmitSingle('AIPF')
    When line = '#BV_Package_View_1#' Then
      Call EmitPackage('BV_Package_View_1')
    When line = '#BV_Package_View_2#' Then
      Call EmitPackage('BV_Package_View_2')
    When line = '#BV_Package_1#' Then
      Call EmitPackage('BV_Package_1')
    When line = '#BV_Package_2#' Then
      Call EmitPackage('BV_Package_2')
    When line = '#BV_Package_3#' Then
      Call EmitPackage('BV_Package_3')
    When line = '#BV_Package_4#' Then
      Call EmitPackage('BV_Package_4')
    When line = '#BV_Package_5#' Then
      Call EmitPackage('BV_Package_5')
    When line = '#BV_Package_6#' Then
      Call EmitPackage('BV_Package_6')
    When line = '#BV_Package_7#' Then
      Call EmitPackage('BV_Package_7')
    When line = '#BV_Package_8#' Then
      Call EmitPackage('BV_Package_8')
    When line = '#BV_Package_9#' Then
      Call EmitPackage('BV_Package_9')
    When line = '#BV_Package_10#' Then
      Call EmitPackage('BV_Package_10')
    When line = '#BV_Package_11#' Then
      Call EmitPackage('BV_Package_11')
    When line = '#BV_Package_12#' Then
      Call EmitPackage('BV_Package_12')
    When line = '#BV_Package_13#' Then
      Call EmitPackage('BV_Package_13')
    When line = '#BV_Package_14#' Then
      Call EmitPackage('BV_Package_14')
    When line = '#BV_Package_15#' Then
      Call EmitPackage('BV_Package_15')
    When line = '#BV_Package_16#' Then
      Call EmitPackage('BV_Package_16')
    When line = '#BV_Package_17#' Then
      Call EmitPackage('BV_Package_17')
    When line = '#BV_Package_18#' Then
      Call EmitPackage('BV_Package_18')
    When line = '#BV_Package_19#' Then
      Call EmitPackage('BV_Package_19')
    When line = '#BV_Package_20#' Then
      Call EmitPackage('BV_Package_20')
    When line = '#BV_Package_21#' Then
      Call EmitPackage('BV_Package_21')
    When start = '//' Then
      NOP
    When line = '' Then
      NOP
    Otherwise
      Do
        if (onlytag = '[VBV]') Then
        Do
          line = right(line,length(line) - 5);
          rc = lineout(Output1File,line)
        End
        Else if (onlytag = '[RCM]') Then
        Do
          line = right(line,length(line) - 5);
          Call SplitOutput(Output2File line)
        End
        Else
        Do
          rc = lineout(Output1File,line)
          Call SplitOutput(Output2File line)
        End
      End
  End
End
/* Produce the Class objects - allows VBV to show RODM classes */
line = linein(ClassFile)

do while line <> ""
  parse var line className ',' descriptiveClassName
  Call LINEOUT Output1File,'[Description]'
  if (className <> "*") then
  Do
    rc = lineout(Output1File,descriptiveClassName '('className')')
  End
  else
  Do
    className = descriptiveClassname
    rc = lineout(Output1File,descriptiveClassName)
  End
  rc = lineout(Output1File,'[RODM class]')
  rc = lineout(Output1File,className)
  rc = lineout(Output1File,'[Object type]')
  rc = lineout(Output1File,'RODMClass')
  rc = lineout(Output1File,'[AggChild type]')
  rc = lineout(Output1File,'N/A')
  rc = lineout(Output1File,'')

  line = linein(ClassFile)
end
return

/***********************************************************************************/
/* SplitOutput                                                                     */
/***********************************************************************************/
/*                                                                                 */
/***********************************************************************************/
SplitOutput:
parse arg filename bigLine
offset = 0;
lineLen = 72 - 3; /* 72 characters, minus 3 for '||,' appendix */
  if length(bigLine) > linelen Then
  Do
    totalLen = length(bigLine);
    pos = 1;
    lastPos = totalLen;
    Do while (pos < lastPos)
      if (lastPos - pos > lineLen) Then
      Do
        tempLine = substr(bigLine,pos,lineLen);
        if (substr(bigline,pos+linelen,1) = '*') Then
        Do
          tempLine = substr(bigLine,pos,lineLen - 1);
          offset = -1;
        End
        tempLine = tempLine||'||,'
        rc = lineout(filename,tempLine)
        pos = pos + lineLen + offset;
        offset = 0;
      End
      Else
      Do
        tempLine = substr(bigLine,pos,(lastpos - pos + 1));
        rc = lineout(filename,tempLine)
        pos = pos + (lastpos - pos);
      End
    End
  End
  Else
  Do
    rc = lineout(filename,bigLine);
  End
Return 0;

/***********************************************************************************/
/* EmitPackage                                                                     */
/***********************************************************************************/
/*                                                                                 */
/***********************************************************************************/
EmitPackage:
parse arg varname
  num = value(varname'.0')
  Do i = 1 to num
    Call EmitSingle(value(varname'.'i))
  End
Return;


/***********************************************************************************/
/* EmitSingle                                                                      */
/***********************************************************************************/
/*                                                                                 */
/***********************************************************************************/
EmitSingle:
parse arg esvarname
  rc = lineout(Output1File,'[Control]')
  temp = value(esvarname'.1')
  rc = lineout(Output1File,temp)
  rc = lineout(Output1File,'[Card]')
  temp = value(esvarname'.2')
  rc = lineout(Output1File,temp)
  rc = lineout(Output1File,'[Type]')
  temp = value(esvarname'.3')
  rc = lineout(Output1File,temp)
  rc = lineout(Output1File,'[Help]')
  temp = value(esvarname'.5')
  rc = lineout(Output1File,temp)
  rc = lineout(Output1File,'[Choice]')
  temp = value(esvarname'.4')
  rc = lineout(Output1File,temp)
Return;


/***********************************************************************************/
/* ReadCommonParms                                                                 */
/***********************************************************************************/
/*                                                                                 */
/***********************************************************************************/
ReadCommonParms:

/* Text, Checkbox, Spin */
TextControl='Text'
CheckboxControl='Checkbox'
Spin='Spin'

/* 1 = Descriptive text */
/* 2 = BLDVIEWS control statement */
/* 3 = GUI Control type */
/* 4 = Initializer (list) */
/* 5 = Help identifier (integer) */

Activate.0=5
Activate.1='Activate'
Activate.2='ACTIVATE'
Activate.3=TextControl
Activate.4='""'
Activate.5='1004'

AggChildClass.0=5
AggChildClass.1='Class'
AggChildClass.2='CLASS'
AggChildClass.3=TextControl
AggChildClass.4='""'
AggChildClass.5='1030'

AggChildLink.0=5
AggChildLink.1='Parent/Child Access link'
AggChildLink.2='PARENT_CHILD_LINK'
AggChildLink.3=Spin
AggChildLink.4='""|YES|NO'
AggChildLink.5='1031'

AggChildType.0=5
AggChildType.1='Type'
AggChildType.2='TYPE'
AggChildType.3=Spin
AggChildType.4=''
AggChildType.4=AggChildType.4 || 'ADAPTER|AGG|APPL_MAJNODE|APPN_CLUSTER|APPN_NETWORK|APPN_TG_CIRCUIT|APPN_VRN|'
AggChildType.4=AggChildType.4 || 'CA_MAJNODE|CDRM|CDRM_MAJNODE|CDRSC|CDRSC_MAJNODE|CN_CIRCUIT|DOMAIN|ENODE|HOST_NODE|IC_NODE|INTERFACE|INTER_DOMAIN_CIRCUIT|INTER_SUBNETWORK_CIRCUIT|'
AggChildType.4=AggChildType.4 || 'LCLNONSNA_MAJNODE|LINE|LLINK|'
AggChildType.4=AggChildType.4 || 'LNODE|LOCALSNA_MAJNODE|LU|LUGROUP_MAJNODE|LU_GROUP|MIG_DATA_HOST|NCP_GW|NCP_MAJNODE|NCP_NON_GW|NNODE|NONSNA|'
AggChildType.4=AggChildType.4 || 'NTRI_CIRCUIT|PACKET_MAJNODE|PU|SNALOCALTOPO|SNA_PORT|STATION_ADAPTER|'
AggChildType.4=AggChildType.4 || 'SUBAREA_TG_CIRCUIT|SWITCHED_MAJNODE|SYSTEM|TG|TRL_MAJNODE|XCA_MAJNODE|OTHER'
AggChildType.5='9999'

AggPri.0=5
AggPri.1='Aggregation Priority'
AggPri.2='AGGPRI'
AggPri.3=Spin
AggPri.4='""|-2|-1|0|1|2|3|4|5|6|7|8|9'
AggPri.5='1000'

AggThresh.1='Aggregation Threshold'
AggThresh.2='AGGTHRESH'
AggThresh.3=Spin
AggThresh.4='""|(#1,#2,#3)'
AggThresh.5='1001'

AIPF.1='UserStatus Automation in Progress filter'
AIPF.2='AIPF'
AIPF.3=Spin
AIPF.4='""|IGNORE|ON|OFF'
AIPF.5='1014'

Annotation.1='Annotation'
Annotation.2='ANNOTATION'
Annotation.3=TextControl
Annotation.4='""'
Annotation.5='1016'

ATMClusterBName.1='ATM Cluster'
ATMClusterBName.2='ATMCLUSTER'
ATMClusterBName.3=Spin
ATMClusterBName.4='""|ALL'
ATMClusterBName.5='1023'

ATMClusterQuietName.1='ATM Cluster'
ATMClusterQuietName.2='ATMCLUSTER'
ATMClusterQuietName.3=Spin
ATMClusterQuietName.4='""|ALL'
ATMClusterQuietName.5='1023'

AutoProgress.1='Automation in Progress'
AutoProgress.2='AUTO_IN_PROGRESS'
AutoProgress.3=Spin
AutoProgress.4='""|ON|OFF'
AutoProgress.5='1014'

Column.1='Column'
Column.2='COLUMN'
Column.3=TextControl
Column.4='""'
Column.5='1011'

Console.1='Console'
Console.2='CONSOLE'
Console.3=TextControl
Console.4='""'
Console.5='1002'

Correlator.1='Correlater'
Correlator.2='CORRELATER'
Correlator.3=TextControl
Correlator.4='""'
Correlator.5='1032'

Create.1='Create'
Create.2='CREATE'
Create.3=Spin
Create.4='Yes|No|Build'
Create.5='1019'

CreateView.1='Create'
CreateView.2='CREATE'
CreateView.3=Spin
CreateView.4='Yes|No|Build'
CreateView.5='1018'

Deactivate.1='Deactivate'
Deactivate.2='DEACTIVATE'
Deactivate.3=TextControl
Deactivate.4='""'
Deactivate.5='1004'

DetailLink.1='Detail Link'
DetailLink.2='DETAIL_LINK'
DetailLink.3=Spin
DetailLink.4='""|LOGICAL|PHYSICAL'
DetailLink.5='1006'

Display.1='Display'
Display.2='DISPLAY'
Display.3=TextControl
Display.4='""'
Display.5='1004'

DisplayName.1='Display Name'
DisplayName.2='DISPLAY_NAME'
DisplayName.3=TextControl
DisplayName.4='""'
DisplayName.5='1005'

DisplayStatus.1='DisplayStatus'
DisplayStatus.2='DISPLAY_STATUS'
DisplayStatus.3=Spin
DisplayStatus.4='""|129|144|145|130|160|161|131|132|133|134|136|137|138|139|140|141|142|143|152|153|154|155|156|157|158|159'
DisplayStatus.5='1003'

DSF.1='Display Status Filter'
DSF.2='DSF'
DSF.3=Spin
DSF.4='""|IGNORE|NOXCPT'
DSF.5='1007'

Domain.1='Domain'
Domain.2='DOMAIN'
Domain.3=TextControl
Domain.4='""'
Domain.5='1024'

ExceptionViewName.1='Exception View Name'
ExceptionViewName.2='EVIEW_NAME'
ExceptionViewName.3=TextControl
ExceptionViewName.4='""'
ExceptionViewName.5='1025'

GMFHSAggType.1='Type'
GMFHSAggType.2='TYPE'
GMFHSAggType.3=Spin
GMFHSAggType.4=''
GMFHSAggType.4=GMFHSAggType.4 || 'USER|APPN_CLUSTER|APPN_DOMAIN|APPN_NETWORK|'
GMFHSAggType.4=GMFHSAggType.4 || 'SNALOCALTOPO|SYSTEM|'
GMFHSAggType.5='9999'

Layout.1='Layout'
Layout.2='LAYOUT'
Layout.3=Spin
Layout.4='""|1|2|3|4|5|6|7|8|9'
Layout.5='1017'

LayoutWidth.1='Layout Width'
LayoutWidth.2='LAYOUT_WIDTH'
LayoutWidth.3=Spin
LayoutWidth.4='""|0'
LayoutWidth.5='1015'

ManNodeName.1='Managed Node Name'
ManNodeName.2='MANNODE'
ManNodeName.3=Spin
ManNodeName.4='""|ALL'
ManNodeName.5='1033'

Mark.1='Mark'
Mark.2='MARK'
Mark.3=Spin
Mark.4='""|ON|OFF'
Mark.5='1014'

MF.1='UserStatus Mark Filter'
MF.2='MF'
MF.3=Spin
MF.4='""|IGNORE|ON|OFF'
MF.5 ='1014'

NonSNADRT.1='Display Resource Type'
NonSNADRT.2=TYPE
NonSNADRT.3=Spin
NonSNADRT.4 = '';
NonSNADRT.4 = NonSNADRT.4||'DUIXC_LTA_APPN_TG_CIRCUIT|DUIXC_LTA_APPN_TRN_GROUP|DUIXC_LTA_INT_DOMAIN_CIR_AGG|DUIXC_LTA_INT_DOM_NET_CIR_AGG|DUIXC_LTN_APPN_TG_CIRCUIT|DUIXC_LTN_APPN_TG_CIR_CN|DUIXC_LTN_APPN_TG_CIR_NTRI|DUIXC_LTN_APPN_TRN_GROUP|DUIXC_LTN_BRIDGE_LINK|DUIXC_LTN_BRIDG'
NonSNADRT.4 = NonSNADRT.4||'E_LINK_AGG|DUIXC_LTN_BUS|DUIXC_LTN_CHAN_ATTACH|DUIXC_LTN_CHAN_CKT|DUIXC_LTN_CIRCUIT_LINK_AGG|DUIXC_LTN_CKT_GROUP|DUIXC_LTN_CLUSTER_CONN|DUIXC_LTN_DIGITAL_PRI_LINE|DUIXC_LTN_DLC|DUIXC_LTN_DS_CKT_CONN_EQUIP|DUIXC_LTN_FIBER_LINK|DUIXC_LTN_GEN_LINK|DUIXC'
NonSNADRT.4 = NonSNADRT.4||'_LTN_GEN_NULL_LINK|DUIXC_LTN_INTER_TG_CIRCUIT|DUIXC_LTN_INT_DOMAIN_CIR_AGG|DUIXC_LTN_INT_DOM_NET_CIR_AGG|DUIXC_LTN_INT_DOM_NET_CLU_CIR|DUIXC_LTN_INT_NET_CIR_AGG|DUIXC_LTN_INT_NET_CLU_CIR_AGG|DUIXC_LTN_IP_LINK|DUIXC_LTN_IP_LINK_AGG|DUIXC_LTN_LINK|DUIX'
NonSNADRT.4 = NonSNADRT.4||'C_LTN_LINK_AGG|DUIXC_LTN_LINK_AGG_USER1|DUIXC_LTN_LINK_AGG_USER10|DUIXC_LTN_LINK_AGG_USER11|DUIXC_LTN_LINK_AGG_USER12|DUIXC_LTN_LINK_AGG_USER13|DUIXC_LTN_LINK_AGG_USER14|DUIXC_LTN_LINK_AGG_USER15|DUIXC_LTN_LINK_AGG_USER16|DUIXC_LTN_LINK_AGG_USER2|DUI'
NonSNADRT.4 = NonSNADRT.4||'XC_LTN_LINK_AGG_USER3|DUIXC_LTN_LINK_AGG_USER4|DUIXC_LTN_LINK_AGG_USER5|DUIXC_LTN_LINK_AGG_USER6|DUIXC_LTN_LINK_AGG_USER7|DUIXC_LTN_LINK_AGG_USER8|DUIXC_LTN_LINK_AGG_USER9|DUIXC_LTN_LINK_GROUP|DUIXC_LTN_LINK_USER1|DUIXC_LTN_LINK_USER10|DUIXC_LTN_LINK'
NonSNADRT.4 = NonSNADRT.4||'_USER11|DUIXC_LTN_LINK_USER12|DUIXC_LTN_LINK_USER13|DUIXC_LTN_LINK_USER14|DUIXC_LTN_LINK_USER15|DUIXC_LTN_LINK_USER16|DUIXC_LTN_LINK_USER2|DUIXC_LTN_LINK_USER3|DUIXC_LTN_LINK_USER4|DUIXC_LTN_LINK_USER5|DUIXC_LTN_LINK_USER6|DUIXC_LTN_LINK_USER7|DUIXC_'
NonSNADRT.4 = NonSNADRT.4||'LTN_LINK_USER8|DUIXC_LTN_LINK_USER9|DUIXC_LTN_LOCAL_LINK|DUIXC_LTN_LOG_LINK|DUIXC_LTN_LOG_LINK_CIRCUIT|DUIXC_LTN_LOG_LINK_CIR_AGG|DUIXC_LTN_LOOP|DUIXC_LTN_MULTIPT_CKT|DUIXC_LTN_PERSPECTIVE_LINK|DUIXC_LTN_PORT_CIRCUIT|DUIXC_LTN_PORT_CIR_AGG|DUIXC_LTN_'
NonSNADRT.4 = NonSNADRT.4||'PRI_ANALOG_LINE|DUIXC_LTN_PUB_SWIT_LINE|DUIXC_LTN_RING|DUIXC_LTN_SUBAREA_TG_CIR_AGG|DUIXC_LTN_SUBRATE_DC|DUIXC_LTN_TG|DUIXC_LTN_TG_CIRCUIT|DUIXC_LTN_TG_CIR_AGG|DUIXC_LTN_UNGUIDED_LINK|DUIXC_LTN_VIRTUAL_TG_CIRCUIT|DUIXC_LTN_WIRE_LINK|DUIXC_LTS_APPL_CO'
NonSNADRT.4 = NonSNADRT.4||'NN|DUIXC_LTS_CLUSTER_CONN|DUIXC_LTS_ETHERNET_P_LINK|DUIXC_LTS_FRAME_L_LINK|DUIXC_LTS_FRAME_P_LINK|DUIXC_LTS_GENERIC_LINK|DUIXC_LTS_GW_CONN|DUIXC_LTS_HOST_HOST_CHAN|DUIXC_LTS_HOST_HOST_CHAN_AGG|DUIXC_LTS_HOST_NCP_CHAN|DUIXC_LTS_HOST_NCP_CHAN_AGG|DUIXC'
NonSNADRT.4 = NonSNADRT.4||'_LTS_HOST_NCP_CONN|DUIXC_LTS_LOCAL_SNA_CONN|DUIXC_LTS_LU_CONN|DUIXC_LTS_MP_CONN|DUIXC_LTS_NSWIT_LINK|DUIXC_LTS_NSWIT_LINK_AGG|DUIXC_LTS_NTRI_LOGICAL|DUIXC_LTS_NTRI_PHYSICAL|DUIXC_LTS_NULL_CONN|DUIXC_LTS_PERIPH_CHANNEL|DUIXC_LTS_PERIPH_LINK|DUIXC_LTS_'
NonSNADRT.4 = NonSNADRT.4||'SNA_LINE_AGG|DUIXC_LTS_SWIT_CONN|DUIXC_LTS_SWIT_LINK|DUIXC_LTS_SWIT_LINK_AGG|DUIXC_LTS_TG|DUIXC_RTA_APPN_EN|DUIXC_RTA_APPN_NN|DUIXC_RTA_EN_LOCAL_TOP_AGG|DUIXC_RTA_INTERCHANGE_NODE|DUIXC_RTA_LEN_NODE|DUIXC_RTA_LOGICAL_LINK_PU|DUIXC_RTA_MIGRATION_DATA_'
NonSNADRT.4 = NonSNADRT.4||'HOST|DUIXC_RTA_NN_DOMAIN_AGG|DUIXC_RTA_NN_DOMAIN_NETWORK|DUIXC_RTA_NN_DOM_NET_CLUSTER|DUIXC_RTA_NN_LOCAL_TOP_AGG|DUIXC_RTA_PORT|DUIXC_RTA_T2_1_NODE|DUIXC_RTA_VIR_ROUTING_NODE|DUIXC_RTN_3270_EMUL|DUIXC_RTN_8209_ADAPTER|DUIXC_RTN_8230_CAU|DUIXC_RTN_ACC'
NonSNADRT.4 = NonSNADRT.4||'ESS_SUPPORT|DUIXC_RTN_ADAPTER|DUIXC_RTN_ADDL_SERVER|DUIXC_RTN_AGENT|DUIXC_RTN_AIX_SYSTEM|DUIXC_RTN_ANALOG_MODEM|DUIXC_RTN_APPL|DUIXC_RTN_APPL_ACCESS_PATH|DUIXC_RTN_APPL_AGG_USER1|DUIXC_RTN_APPL_AGG_USER10|DUIXC_RTN_APPL_AGG_USER11|DUIXC_RTN_APPL_AGG_'
NonSNADRT.4 = NonSNADRT.4||'USER12|DUIXC_RTN_APPL_AGG_USER13|DUIXC_RTN_APPL_AGG_USER14|DUIXC_RTN_APPL_AGG_USER15|DUIXC_RTN_APPL_AGG_USER16|DUIXC_RTN_APPL_AGG_USER2|DUIXC_RTN_APPL_AGG_USER3|DUIXC_RTN_APPL_AGG_USER4|DUIXC_RTN_APPL_AGG_USER5|DUIXC_RTN_APPL_AGG_USER6|DUIXC_RTN_APPL'
NonSNADRT.4 = NonSNADRT.4||'_AGG_USER7|DUIXC_RTN_APPL_AGG_USER8|DUIXC_RTN_APPL_AGG_USER9|DUIXC_RTN_APPL_GROUP|DUIXC_RTN_APPL_SUBSYS|DUIXC_RTN_APPL_USER1|DUIXC_RTN_APPL_USER10|DUIXC_RTN_APPL_USER11|DUIXC_RTN_APPL_USER12|DUIXC_RTN_APPL_USER13|DUIXC_RTN_APPL_USER14|DUIXC_RTN_APPL_'
NonSNADRT.4 = NonSNADRT.4||'USER15|DUIXC_RTN_APPL_USER16|DUIXC_RTN_APPL_USER2|DUIXC_RTN_APPL_USER3|DUIXC_RTN_APPL_USER4|DUIXC_RTN_APPL_USER5|DUIXC_RTN_APPL_USER6|DUIXC_RTN_APPL_USER7|DUIXC_RTN_APPL_USER8|DUIXC_RTN_APPL_USER9|DUIXC_RTN_APPN_BRNN|DUIXC_RTN_APPN_EN|DUIXC_RTN_APPN_'
NonSNADRT.4 = NonSNADRT.4||'NETWORK|DUIXC_RTN_APPN_NET_CLUSTER|DUIXC_RTN_APPN_NN|DUIXC_RTN_APPN_SUBNET_AGG|DUIXC_RTN_APPN_SUBNET_BN_AGG|DUIXC_RTN_APP_LAN_DOMAIN_AGG|DUIXC_RTN_AS_400|DUIXC_RTN_AS_400_AGG|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_BRIDGE|DUIXC_RTN_BRIDGE_AGG|DUIXC_RTN_BRIDGE_APPL|DUIXC_RTN_BRIDGE_CONN|DUIXC_RTN_BUFFER|DUIXC_RTN_BUFFER_POOL|DUIXC_RTN_CAR'
NonSNADRT.4 = NonSNADRT.4||'D_RDR|DUIXC_RTN_CARD_RDR_PUNCH|DUIXC_RTN_CAU_ADAPTER|DUIXC_RTN_CDRM|DUIXC_RTN_CHANNEL_BANK|DUIXC_RTN_CHAN_ADAPTER|DUIXC_RTN_CHECK_RDR|DUIXC_RTN_CICSPLEX_AGG|DUIXC_RTN_CICS_SYSTEM|DUIXC_RTN_CLIENT_TERMINAL|DUIXC_RTN_CLSTR_CTRL_AGG|DUIXC_RTN_CLUSTER_CT'
NonSNADRT.4 = NonSNADRT.4||'RL|DUIXC_RTN_CLUSTER_USER1|DUIXC_RTN_CLUSTER_USER10|DUIXC_RTN_CLUSTER_USER11|DUIXC_RTN_CLUSTER_USER12|DUIXC_RTN_CLUSTER_USER13|DUIXC_RTN_CLUSTER_USER14|DUIXC_RTN_CLUSTER_USER15|DUIXC_RTN_CLUSTER_USER16|DUIXC_RTN_CLUSTER_USER2|DUIXC_RTN_CLUSTER_USER3|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_CLUSTER_USER4|DUIXC_RTN_CLUSTER_USER5|DUIXC_RTN_CLUSTER_USER6|DUIXC_RTN_CLUSTER_USER7|DUIXC_RTN_CLUSTER_USER8|DUIXC_RTN_CLUSTER_USER9|DUIXC_RTN_CNTL_PT_APPL|DUIXC_RTN_COIN_FEED|DUIXC_RTN_COLL_OF_SPOTS_AGG|DUIXC_RTN_COMM_ADAPTER|DUIXC_RTN_CO'
NonSNADRT.4 = NonSNADRT.4||'MM_CTRL|DUIXC_RTN_COMM_GATEWAY|DUIXC_RTN_COMM_GATEWAY_AGG|DUIXC_RTN_COMM_SER|DUIXC_RTN_COMM_SITE_CLUSTER|DUIXC_RTN_CONCENTRATOR|DUIXC_RTN_CONCENTRATOR_AGG|DUIXC_RTN_CONN|DUIXC_RTN_CONN_AGG_USER1|DUIXC_RTN_CONN_AGG_USER10|DUIXC_RTN_CONN_AGG_USER11|DUI'
NonSNADRT.4 = NonSNADRT.4||'XC_RTN_CONN_AGG_USER12|DUIXC_RTN_CONN_AGG_USER13|DUIXC_RTN_CONN_AGG_USER14|DUIXC_RTN_CONN_AGG_USER15|DUIXC_RTN_CONN_AGG_USER16|DUIXC_RTN_CONN_AGG_USER2|DUIXC_RTN_CONN_AGG_USER3|DUIXC_RTN_CONN_AGG_USER4|DUIXC_RTN_CONN_AGG_USER5|DUIXC_RTN_CONN_AGG_USER'
NonSNADRT.4 = NonSNADRT.4||'6|DUIXC_RTN_CONN_AGG_USER7|DUIXC_RTN_CONN_AGG_USER8|DUIXC_RTN_CONN_AGG_USER9|DUIXC_RTN_CONN_USER1|DUIXC_RTN_CONN_USER10|DUIXC_RTN_CONN_USER11|DUIXC_RTN_CONN_USER12|DUIXC_RTN_CONN_USER13|DUIXC_RTN_CONN_USER14|DUIXC_RTN_CONN_USER15|DUIXC_RTN_CONN_USER1'
NonSNADRT.4 = NonSNADRT.4||'6|DUIXC_RTN_CONN_USER2|DUIXC_RTN_CONN_USER3|DUIXC_RTN_CONN_USER4|DUIXC_RTN_CONN_USER5|DUIXC_RTN_CONN_USER6|DUIXC_RTN_CONN_USER7|DUIXC_RTN_CONN_USER8|DUIXC_RTN_CONN_USER9|DUIXC_RTN_CONTROL_PGM|DUIXC_RTN_CONTROL_PT_NODE|DUIXC_RTN_CONTROL_UNIT|DUIXC_RTN'
NonSNADRT.4 = NonSNADRT.4||'_COOLING_UNIT|DUIXC_RTN_COUPLING_FACILITY|DUIXC_RTN_COUPLING_FAC_AGG|DUIXC_RTN_CROSS_DOMAIN_RES|DUIXC_RTN_CRPTO_UNIT|DUIXC_RTN_CSU|DUIXC_RTN_CTRLED_ACC_UNIT|DUIXC_RTN_DASD|DUIXC_RTN_DATASET|DUIXC_RTN_DATASET_AGG|DUIXC_RTN_DATA_CNTR_CLUSTER|DUIXC_RTN_'
NonSNADRT.4 = NonSNADRT.4||'DATA_TABLE|DUIXC_RTN_DBM|DUIXC_RTN_DB_REQ|DUIXC_RTN_DEFINITION_GROUP|DUIXC_RTN_DH_LOCAL_TOP_AGG|DUIXC_RTN_DIAL_BU_UNIT|DUIXC_RTN_DIGITAL_MODEM|DUIXC_RTN_DIR_ATT_LK_ADAPTER|DUIXC_RTN_DISK_JOURNAL|DUIXC_RTN_DL_ENTITY|DUIXC_RTN_DOC_FEED|DUIXC_RTN_DOMAIN'
NonSNADRT.4 = NonSNADRT.4||'|DUIXC_RTN_DOMAIN_AGG|DUIXC_RTN_DOMAIN_MGR|DUIXC_RTN_DOM_CTRL|DUIXC_RTN_DOS_SYSTEM|DUIXC_RTN_DSA|DUIXC_RTN_DSU|DUIXC_RTN_DTS|DUIXC_RTN_ECHO_CANCELLER|DUIXC_RTN_ECS|DUIXC_RTN_EMS|DUIXC_RTN_ENCRYPTOR|DUIXC_RTN_END_NODE|DUIXC_RTN_ENTITY_MGR|DUIXC_RTN_EN'
NonSNADRT.4 = NonSNADRT.4||'VELOPE_DEP|DUIXC_RTN_EN_LOCAL_TOP_AGG|DUIXC_RTN_ETHERNET_AGG|DUIXC_RTN_EXTRAPART_TDQ|DUIXC_RTN_FAN|DUIXC_RTN_FAX|DUIXC_RTN_FEP|DUIXC_RTN_FEP_AGG|DUIXC_RTN_FEP_HOST|DUIXC_RTN_FILE_SERVER|DUIXC_RTN_FILE_SER_AGG|DUIXC_RTN_FILE_SER_APPL|DUIXC_RTN_FIRMWAR'
NonSNADRT.4 = NonSNADRT.4||'E|DUIXC_RTN_GATEWAY|DUIXC_RTN_GATEWAY_ROUTER|DUIXC_RTN_GENERIC_MAJ_NODE|DUIXC_RTN_GENERIC_MIN_NODE|DUIXC_RTN_GENERIC_MODEM|DUIXC_RTN_GENERIC_TERM|DUIXC_RTN_GEN_NODE|DUIXC_RTN_GEN_NULL_NODE|DUIXC_RTN_GEN_TRANSCEIVER|DUIXC_RTN_GROUP_AGG|DUIXC_RTN_GW_IW'
NonSNADRT.4 = NonSNADRT.4||'S|DUIXC_RTN_HOST|DUIXC_RTN_HOST_ACCESS_PATH|DUIXC_RTN_HOST_AGG|DUIXC_RTN_HOST_AGG_USER1|DUIXC_RTN_HOST_AGG_USER10|DUIXC_RTN_HOST_AGG_USER11|DUIXC_RTN_HOST_AGG_USER12|DUIXC_RTN_HOST_AGG_USER13|DUIXC_RTN_HOST_AGG_USER14|DUIXC_RTN_HOST_AGG_USER15|DUIXC_'
NonSNADRT.4 = NonSNADRT.4||'RTN_HOST_AGG_USER16|DUIXC_RTN_HOST_AGG_USER2|DUIXC_RTN_HOST_AGG_USER3|DUIXC_RTN_HOST_AGG_USER4|DUIXC_RTN_HOST_AGG_USER5|DUIXC_RTN_HOST_AGG_USER6|DUIXC_RTN_HOST_AGG_USER7|DUIXC_RTN_HOST_AGG_USER8|DUIXC_RTN_HOST_AGG_USER9|DUIXC_RTN_HOST_USER1|DUIXC_RTN'
NonSNADRT.4 = NonSNADRT.4||'_HOST_USER10|DUIXC_RTN_HOST_USER11|DUIXC_RTN_HOST_USER12|DUIXC_RTN_HOST_USER13|DUIXC_RTN_HOST_USER14|DUIXC_RTN_HOST_USER15|DUIXC_RTN_HOST_USER16|DUIXC_RTN_HOST_USER2|DUIXC_RTN_HOST_USER3|DUIXC_RTN_HOST_USER4|DUIXC_RTN_HOST_USER5|DUIXC_RTN_HOST_USER6|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_HOST_USER7|DUIXC_RTN_HOST_USER8|DUIXC_RTN_HOST_USER9|DUIXC_RTN_IC_LOCAL_TOP_AGG|DUIXC_RTN_INDIRECT_TDQ|DUIXC_RTN_INTERCHANGE_NODE|DUIXC_RTN_INTERNET|DUIXC_RTN_INTERNET_AGG|DUIXC_RTN_INTERNET_HOST|DUIXC_RTN_INTERNET_HOST_AGG|DUIXC_RTN_INTERN'
NonSNADRT.4 = NonSNADRT.4||'ET_ROUTER|DUIXC_RTN_INTERNET_ROUTER_AGG|DUIXC_RTN_INTRAPART_TDQ|DUIXC_RTN_IO_MODULE_AGG|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_KEYBOARD|DUIXC_RTN_LANDP_MANAGER|DUIXC_RTN_LANGUAGE|DUIXC_RTN_LAN_ADAPTER|DUIXC_RTN_LAN_AGG|DUIXC_RTN_LAN_BRIDGE|DUIXC_RTN_LAN_BRIDGE_ADPTR|DUIXC_RTN_LAN_CONCENT_AGG|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_LAN_DB_NET_AGG|DUIXC_RTN_LAN_DOMAIN_AGG|DUIXC_RTN_LAN_FILE_SERVER|DUIXC_RTN_LAN_NETWORK_AGG|DUIXC_RTN_LAN_NETWORK_MGR|DUIXC_RTN_LAN_PRINT_SERVER|DUIXC_RTN_LAN_REQ|DUIXC_RTN_LAN_REQUESTER|DUIXC_RTN_LAN_ROUTER|DUIXC_RTN_LAN_SEGMENT|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_LAN_SEGMENT2_AGG|DUIXC_RTN_LAN_SEGMENT_AGG|DUIXC_RTN_LAN_SERVER|DUIXC_RTN_LAN_STATION_ADPTR|DUIXC_RTN_LAN_SVR_NET_AGG|DUIXC_RTN_LAN_WKSTN_AGG|DUIXC_RTN_LEN_NODE|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_LOCAL_FILE|DUIXC_RTN_LOCAL_TRANS|DUIXC_RTN_LOGICAL_LINK_PU|DUIXC_RTN_LOGICAL_UNIT|DUIXC_RTN_LOOP_ADAPTER|DUIXC_RTN_LSRPOOL|DUIXC_RTN_LT_CLIENT_AGG|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_LU62_CONN|DUIXC_RTN_LU62_CONV|DUIXC_RTN_LU62_SESSION|DUIXC_RTN_LU_GROUP|DUIXC_RTN_LU_GROUP_NODE|DUIXC_RTN_MAC_SYSTEM|DUIXC_RTN_MAG_STRIPE_RDR|DUIXC_RTN_MAINT_DEVICE|DUIXC_RTN_MANAGED_REGION_AGG|DUIXC_RTN_MANAGER|DUIXC_R'
NonSNADRT.4 = NonSNADRT.4||'TN_MAN_AGG|DUIXC_RTN_MATRIX_SWITCH|DUIXC_RTN_MAU|DUIXC_RTN_MEMORY|DUIXC_RTN_MGD_NODE_AGG|DUIXC_RTN_MICROCODE|DUIXC_RTN_MICROWAVE_EQUIP|DUIXC_RTN_MIGRATION_DATA_HOST|DUIXC_RTN_MINI|DUIXC_RTN_MINI_AGG|DUIXC_RTN_MIXED_CLUSTER|DUIXC_RTN_MODENAME|DUIXC_RT'
NonSNADRT.4 = NonSNADRT.4||'N_MONITOR|DUIXC_RTN_MONITOR_MGR|DUIXC_RTN_MRO_CONN|DUIXC_RTN_MRO_CONV|DUIXC_RTN_MRO_SESSION|DUIXC_RTN_MULTIPORT_JUNCTION|DUIXC_RTN_MUX|DUIXC_RTN_MUX_AGG|DUIXC_RTN_NETFIN_CLIENT|DUIXC_RTN_NETFIN_MGR|DUIXC_RTN_NETFIN_SERVER|DUIXC_RTN_NETFIN_SERVICES|DU'
NonSNADRT.4 = NonSNADRT.4||'IXC_RTN_NETWARE_SYSTEM|DUIXC_RTN_NETWORK_AGG|DUIXC_RTN_NETWORK_INTFACE|DUIXC_RTN_NETWORK_MGMT|DUIXC_RTN_NETWORK_MGR|DUIXC_RTN_NETWORK_NODE|DUIXC_RTN_NN_DOMAIN_AGG|DUIXC_RTN_NN_DOMAIN_NETWORK|DUIXC_RTN_NN_DOM_NET_CLUSTER|DUIXC_RTN_NN_LOCAL_TOP_AGG|DUI'
NonSNADRT.4 = NonSNADRT.4||'XC_RTN_NODE|DUIXC_RTN_NODE_AGG|DUIXC_RTN_NODE_AGG_USER1|DUIXC_RTN_NODE_AGG_USER10|DUIXC_RTN_NODE_AGG_USER11|DUIXC_RTN_NODE_AGG_USER12|DUIXC_RTN_NODE_AGG_USER13|DUIXC_RTN_NODE_AGG_USER14|DUIXC_RTN_NODE_AGG_USER15|DUIXC_RTN_NODE_AGG_USER16|DUIXC_RTN_NO'
NonSNADRT.4 = NonSNADRT.4||'DE_AGG_USER2|DUIXC_RTN_NODE_AGG_USER3|DUIXC_RTN_NODE_AGG_USER4|DUIXC_RTN_NODE_AGG_USER5|DUIXC_RTN_NODE_AGG_USER6|DUIXC_RTN_NODE_AGG_USER7|DUIXC_RTN_NODE_AGG_USER8|DUIXC_RTN_NODE_AGG_USER9|DUIXC_RTN_NODE_LAN_SERVER|DUIXC_RTN_NODE_USER1|DUIXC_RTN_NODE_'
NonSNADRT.4 = NonSNADRT.4||'USER10|DUIXC_RTN_NODE_USER11|DUIXC_RTN_NODE_USER12|DUIXC_RTN_NODE_USER13|DUIXC_RTN_NODE_USER14|DUIXC_RTN_NODE_USER15|DUIXC_RTN_NODE_USER16|DUIXC_RTN_NODE_USER2|DUIXC_RTN_NODE_USER3|DUIXC_RTN_NODE_USER4|DUIXC_RTN_NODE_USER5|DUIXC_RTN_NODE_USER6|DUIXC_'
NonSNADRT.4 = NonSNADRT.4||'RTN_NODE_USER7|DUIXC_RTN_NODE_USER8|DUIXC_RTN_NODE_USER9|DUIXC_RTN_NON_SNA_CLUSTER|DUIXC_RTN_NPT_TERMINAL|DUIXC_RTN_NTF_DOM_AGG|DUIXC_RTN_NT_BKUP_CTRL|DUIXC_RTN_NT_DOM_AGG|DUIXC_RTN_NT_PRI_CTRL|DUIXC_RTN_NT_SERVER|DUIXC_RTN_NT_WRKSTN|DUIXC_RTN_NULL_N'
NonSNADRT.4 = NonSNADRT.4||'ODE|DUIXC_RTN_NW_FILE_REQUESTER|DUIXC_RTN_NW_FILE_SERVER|DUIXC_RTN_NW_MANAGER|DUIXC_RTN_OPEN_SYSTEM_AGG|DUIXC_RTN_OPERAT_SYS|DUIXC_RTN_OPER_VIEW_AGG|DUIXC_RTN_OPTICAL_SCANNER|DUIXC_RTN_OS2_SYSTEM|DUIXC_RTN_OS400_SYSTEM|DUIXC_RTN_PAD|DUIXC_RTN_PAPER_F'
NonSNADRT.4 = NonSNADRT.4||'EED|DUIXC_RTN_PARALLEL_BRIDGE|DUIXC_RTN_PBX|DUIXC_RTN_PBX_AGG|DUIXC_RTN_PC_NETWORK_AGG|DUIXC_RTN_PC_NET_SEG_AGG|DUIXC_RTN_PERF_MONITOR|DUIXC_RTN_PGM_PROCESS|DUIXC_RTN_PHYS_LAYER_ENTITY|DUIXC_RTN_PKGE_SWITCH_EQUIP|DUIXC_RTN_PLOTTER|DUIXC_RTN_POLICY_RE'
NonSNADRT.4 = NonSNADRT.4||'GION_AGG|DUIXC_RTN_PORT|DUIXC_RTN_PORT2|DUIXC_RTN_POSTSCRIPT_PRT|DUIXC_RTN_POS_TERM|DUIXC_RTN_POWER_SUPPLY|DUIXC_RTN_PRINTER|DUIXC_RTN_PRINT_SERVER|DUIXC_RTN_PRINT_SER_AGG|DUIXC_RTN_PROCESSOR_HOST|DUIXC_RTN_PROCESSOR_NODE|DUIXC_RTN_PROGRAM|DUIXC_RTN_'
NonSNADRT.4 = NonSNADRT.4||'PROTOCOL_CONVERTER|DUIXC_RTN_PROTOCOL_HANDLER|DUIXC_RTN_PRT_SER_APPL|DUIXC_RTN_PWS_AGG|DUIXC_RTN_QUEUE|DUIXC_RTN_QUEUE_AGG|DUIXC_RTN_REGION_CLUSTER|DUIXC_RTN_REL_DATA_BASE|DUIXC_RTN_REMOTE_BRIDGE|DUIXC_RTN_REMOTE_FILE|DUIXC_RTN_REMOTE_LINE_CONC|DUIXC'
NonSNADRT.4 = NonSNADRT.4||'_RTN_REMOTE_TRANS|DUIXC_RTN_REM_OPS_AGENT|DUIXC_RTN_REPEAT_LINE_CNVERT|DUIXC_RTN_RF_MODEM|DUIXC_RTN_RJE|DUIXC_RTN_ROUTE|DUIXC_RTN_ROUTER|DUIXC_RTN_SATELLITE_EQUIP|DUIXC_RTN_SCANNER|DUIXC_RTN_SELECTOR_PEN|DUIXC_RTN_SENSOR|DUIXC_RTN_SERVER|DUIXC_RTN_SE'
NonSNADRT.4 = NonSNADRT.4||'RVICE_PROCESSOR|DUIXC_RTN_SESSION|DUIXC_RTN_SMF_JOURNAL|DUIXC_RTN_SNA_CLUSTER|DUIXC_RTN_SNA_DOMAIN|DUIXC_RTN_SNA_DOMAIN_AGG|DUIXC_RTN_SNA_LOCAL_TOP_AGG|DUIXC_RTN_SNA_NODE|DUIXC_RTN_STATION_ADAPTER|DUIXC_RTN_SUBGROUP_AGG|DUIXC_RTN_SWITCH|DUIXC_RTN_SWI'
NonSNADRT.4 = NonSNADRT.4||'TCH_AGG|DUIXC_RTN_SYSDUMP_CODE|DUIXC_RTN_SYSPLEX_TIMER|DUIXC_RTN_SYSPLEX_TIMER_AGG|DUIXC_RTN_SYSTEM|DUIXC_RTN_SYSTEM_AGG|DUIXC_RTN_SYSTEM_CLUSTER|DUIXC_RTN_SYSTEM_MGR|DUIXC_RTN_T1_RES_MGR|DUIXC_RTN_T2_1_NODE|DUIXC_RTN_TAPE_DRIVE|DUIXC_RTN_TAPE_JOURNA'
NonSNADRT.4 = NonSNADRT.4||'L|DUIXC_RTN_TASK|DUIXC_RTN_TEMP_STOR_QUEUE|DUIXC_RTN_TERM_AGG_USER1|DUIXC_RTN_TERM_AGG_USER10|DUIXC_RTN_TERM_AGG_USER11|DUIXC_RTN_TERM_AGG_USER12|DUIXC_RTN_TERM_AGG_USER13|DUIXC_RTN_TERM_AGG_USER14|DUIXC_RTN_TERM_AGG_USER15|DUIXC_RTN_TERM_AGG_USER16|'
NonSNADRT.4 = NonSNADRT.4||'DUIXC_RTN_TERM_AGG_USER2|DUIXC_RTN_TERM_AGG_USER3|DUIXC_RTN_TERM_AGG_USER4|DUIXC_RTN_TERM_AGG_USER5|DUIXC_RTN_TERM_AGG_USER6|DUIXC_RTN_TERM_AGG_USER7|DUIXC_RTN_TERM_AGG_USER8|DUIXC_RTN_TERM_AGG_USER9|DUIXC_RTN_TERM_USER1|DUIXC_RTN_TERM_USER10|DUIXC_R'
NonSNADRT.4 = NonSNADRT.4||'TN_TERM_USER11|DUIXC_RTN_TERM_USER12|DUIXC_RTN_TERM_USER13|DUIXC_RTN_TERM_USER14|DUIXC_RTN_TERM_USER15|DUIXC_RTN_TERM_USER16|DUIXC_RTN_TERM_USER2|DUIXC_RTN_TERM_USER3|DUIXC_RTN_TERM_USER4|DUIXC_RTN_TERM_USER5|DUIXC_RTN_TERM_USER6|DUIXC_RTN_TERM_USER7'
NonSNADRT.4 = NonSNADRT.4||'|DUIXC_RTN_TERM_USER8|DUIXC_RTN_TERM_USER9|DUIXC_RTN_TEST_EQUIP|DUIXC_RTN_THERMAL_SENSOR|DUIXC_RTN_TOOLS|DUIXC_RTN_TP_MONITOR|DUIXC_RTN_TRACE|DUIXC_RTN_TRANDUMP_CODE|DUIXC_RTN_TRANSACTION_AGG|DUIXC_RTN_TR'
NonSNADRT.4 = NonSNADRT.4||'ANSCEIVER|DUIXC_RTN_TRANS_CLASS|DUIXC_RTN_TRAN_AGG_USER1|DUIXC_RTN_TRAN_AGG_USER10|DUIXC_RTN_TRAN_AGG_USER11|DUIXC_RTN_TRAN_AGG_USER12|DUIXC_RTN_TRAN_AGG_USER13|DUIXC_RTN_TRAN_AGG_USER14|DUIXC_RTN_TRAN_AGG_USER15|DUIXC_RTN_TRAN_AGG_USER16|DUIXC_RTN_T'
NonSNADRT.4 = NonSNADRT.4||'RAN_AGG_USER2|DUIXC_RTN_TRAN_AGG_USER3|DUIXC_RTN_TRAN_AGG_USER4|DUIXC_RTN_TRAN_AGG_USER5|DUIXC_RTN_TRAN_AGG_USER6|DUIXC_RTN_TRAN_AGG_USER7|DUIXC_RTN_TRAN_AGG_USER8|DUIXC_RTN_TRAN_AGG_USER9|DUIXC_RTN_TRAN_USER1|DUIXC_RTN_TRAN_USER10|DUIXC_RTN_TRAN_USE'
NonSNADRT.4 = NonSNADRT.4||'R11|DUIXC_RTN_TRAN_USER12|DUIXC_RTN_TRAN_USER13|DUIXC_RTN_TRAN_USER14|DUIXC_RTN_TRAN_USER15|DUIXC_RTN_TRAN_USER16|DUIXC_RTN_TRAN_USER2|DUIXC_RTN_TRAN_USER3|DUIXC_RTN_TRAN_USER4|DUIXC_RTN_TRAN_USER5|DUIXC_RTN_TRAN_USER6|DUIXC_RTN_TRAN_USER7|DUIXC_RTN_'
NonSNADRT.4 = NonSNADRT.4||'TRAN_USER8|DUIXC_RTN_TRAN_USER9|DUIXC_RTN_TR_SEGMENT|DUIXC_RTN_TR_SEGMENT_AGG|DUIXC_RTN_UNIX_SYSTEM|DUIXC_RTN_USER_APPL|DUIXC_RTN_UTILITY|DUIXC_RTN_VIDEO_EQUIP|DUIXC_RTN_VIR_ROUTING_NODE|DUIXC_RTN_VOLUME|DUIXC_RTN_VOL_GROUP_AGG|DUIXC_RTN_WAN_BRIDGE|D'
NonSNADRT.4 = NonSNADRT.4||'UIXC_RTN_WAN_ROUTER|DUIXC_RTN_WIN95_SYSTEM|DUIXC_RTN_WIN95_WRKSTN|DUIXC_RTN_WINNT_SYSTEM|DUIXC_RTN_WIN_SYSTEM|DUIXC_RTN_WIRING_CLOSET|DUIXC_RTN_WORKGROUP_AGG|DUIXC_RTN_WORK_STN|DUIXC_RTS_APPL_MAJ_NODE|DUIXC_RTS_AS_400|DUIXC_RTS_AS_400_AGG|DUIXC_RTS_C'
NonSNADRT.4 = NonSNADRT.4||'DRM|DUIXC_RTS_CDRM_MAJ_NODE|DUIXC_RTS_CDRSC|DUIXC_RTS_CDRSC_MAJ_NODE|DUIXC_RTS_CHAN_ATT_MAJ_NODE|DUIXC_RTS_CLUSTER|DUIXC_RTS_CNTL_PT_APPL|DUIXC_RTS_COMM_GATEWAY|DUIXC_RTS_COMM_GATEWAY_AGG|DUIXC_RTS_COMM_SER|DUIXC_RTS_COMM_SITE_CLUSTER|DUIXC_RTS_CONTR'
NonSNADRT.4 = NonSNADRT.4||'OL_PT_NODE|DUIXC_RTS_DATA_CNTR_CLUSTER|DUIXC_RTS_GATEWAY_HOST|DUIXC_RTS_GATEWAY_HOST_AGG|DUIXC_RTS_GATEWAY_NCP|DUIXC_RTS_GATEWAY_NCP_AGG|DUIXC_RTS_GENERIC_PU|DUIXC_RTS_HOST|DUIXC_RTS_HOST_AGG|DUIXC_RTS_ICA_MAJ_NODE|DUIXC_RTS_LAN_MAJ_NODE|DUIXC_RTS_LI'
NonSNADRT.4 = NonSNADRT.4||'NK_STATION|DUIXC_RTS_LOC_NSNA_MAJ_NODE|DUIXC_RTS_LOC_SNA_MAJ_NODE|DUIXC_RTS_LU|DUIXC_RTS_NPT_TERMINAL|DUIXC_RTS_NTO_TERMINAL|DUIXC_RTS_NULL_NODE|DUIXC_RTS_PACKET_MAJ_NODE|DUIXC_RTS_PU1|DUIXC_RTS_PU1_ETHERNET|DUIXC_RTS_PU1_FRAME_RELAY|DUIXC_RTS_PU1_NT'
NonSNADRT.4 = NonSNADRT.4||'RI|DUIXC_RTS_PU20|DUIXC_RTS_PU21|DUIXC_RTS_PU4|DUIXC_RTS_PU4_AGG|DUIXC_RTS_SER_PT_APPL|DUIXC_RTS_SER_PT_NODE|DUIXC_RTS_SPC_USE_APP_AGG|DUIXC_RTS_SPC_USE_LU_AGG|DUIXC_RTS_SWITCHED_MAJ_NODE|DUIXC_RTS_SYSTEM_CLUSTER|DUIXC_RTS_TRANSCEIVER|DUIXC_RTS_VTAM_'
NonSNADRT.4 = NonSNADRT.4||'APPL|DUIXC_RTS_XCA_MAJ_NODE'
NonSNADRT.5='9999'

NWServerName.1='Name(s)'
NWServerName.2='NWSERVER'
NWServerName.3=Spin
NWServerName.4='ALL|""'
NWServerName.5='3045'

OtherClass.1='Class'
OtherClass.2='CLASS'
OtherClass.3=TextControl
OtherClass.4='Change_Me_ClassName'
OtherClass.5='1030'

OtherData.1='Other Data'
OtherData.2='OTHER_DATA'
OtherData.3=TextControl
OtherData.4='""'
OtherData.5='1008'

QueryField.1='Query Field'
QueryField.2='QUERYFIELD'
QueryField.3=Spin
QueryField.4='""|DRN|MYNAME'
QueryField.5='1020'

Recycle.1='Recycle'
Recycle.2='RECYCLE'
Recycle.3=TextControl
Recycle.4='""'
Recycle.5='1004'

Row.1='Row'
Row.2='ROW'
Row.3=TextControl
Row.4='""'
Row.5='1009'

SAPF.1='UserStatus SNA Alert Pending Filter'
SAPF.2='SAPF'
SAPF.3=Spin
SAPF.4='""|IGNORE|ON|OFF'
SAPF.5='1021'

Segment.1='Segment'
Segment.2='SEGMENT'
Segment.3=Spin
Segment.4='""|ALL'
Segment.5='1026'

SNADomain.1='SNA Domain'
SNADomain.2='SNA_DOMAIN'
SNADomain.3=TextControl
SNADomain.4='""'
SNADomain.5='1027'

SpanName.1='Span Name(s)'
SpanName.2='SPANNAME'
SpanName.3=TextControl
SpanName.4='""'
SpanName.5='1010'

SPName.1='Service Point Name'
SPName.2='SPNAME'
SPName.3=Spin
SPName.4='""|ALL'
SPName.5='1028'

System.1='System'
System.2='SYSTEM'
System.3=Spin
System.4='""|ALL'
System.5='1029'

TIF.1='UserStatus Threshold Inconsistency Filter'
TIF.2='TIF'
TIF.3=Spin
TIF.4='""|IGNORE|ON|OFF'
TIF.5='1022'

Unlink.1='Unlink'
Unlink.2='UNLINK'
Unlink.3=CheckboxControl
Unlink.4='""'
Unlink.5='1012'

UserData.1='User Data'
UserData.2='USER_DATA'
UserData.3=TextControl
UserData.4='""'
UserData.5='1013'

Wildcard.1='Wildcard Control'
Wildcard.2='WILDCARD'
Wildcard.3=Spin
Wildcard.4='""|(?,*)|*'
Wildcard.5='4002'

Return;


/***********************************************************************************/
/* ReadPackages                                                                    */
/***********************************************************************************/
/*                                                                                 */
/***********************************************************************************/
ReadPackages:

BV_Package_View_1.0 = 3
BV_Package_View_1.1 = Layout
BV_Package_View_1.2 = LayoutWidth
BV_Package_View_1.3 = CreateView

BV_Package_1.0 = 15;
BV_Package_1.1 = SPName
BV_Package_1.2 = AggPri
BV_Package_1.3 = Activate
BV_Package_1.4 = Deactivate
BV_Package_1.5 = Recycle
BV_Package_1.6 = Display
BV_Package_1.7 = Console
BV_Package_1.8 = UserData
BV_Package_1.9 = DisplayStatus
BV_Package_1.10= Correlator
BV_Package_1.11= Unlink
BV_Package_1.12= Row
BV_Package_1.13= Column
BV_Package_1.14= Mark
BV_Package_1.15= AutoProgress

BV_Package_2.0 = 17
BV_Package_2.1 = SPName
BV_Package_2.2 = AggPri
BV_Package_2.3 = AggThresh
BV_Package_2.4 = Activate
BV_Package_2.5 = Deactivate
BV_Package_2.6 = Recycle
BV_Package_2.7 = Display
BV_Package_2.8 = Console
BV_Package_2.9 = UserData
BV_Package_2.10= SpanName
BV_Package_2.11= DisplayStatus
BV_Package_2.12= Correlator
BV_Package_2.13= Unlink
BV_Package_2.14= Row
BV_Package_2.15= Column
BV_Package_2.16= Mark
BV_Package_2.17= AutoProgress

BV_Package_3.0 = 11
BV_Package_3.1 = SPName
BV_Package_3.2 = AggThresh
BV_Package_3.3 = Console
BV_Package_3.4 = UserData
BV_Package_3.5 = DisplayStatus
BV_Package_3.6 = Correlator
BV_Package_3.7 = Unlink
BV_Package_3.8 = Row
BV_Package_3.9 = Column
BV_Package_3.10= Mark
BV_Package_3.11= AutoProgress

BV_Package_4.0 = 17
BV_Package_4.1 = SPName
BV_Package_4.2 = ATMClusterBName
BV_Package_4.3 = AggThresh
BV_Package_4.4 = Activate
BV_Package_4.5 = Deactivate
BV_Package_4.6 = Recycle
BV_Package_4.7 = Display
BV_Package_4.8 = Console
BV_Package_4.9 = UserData
BV_Package_4.10= SpanName
BV_Package_4.11= DisplayStatus
BV_Package_4.12= Correlator
BV_Package_4.13= Unlink
BV_Package_4.14= Row
BV_Package_4.15= Column
BV_Package_4.16= Mark
BV_Package_4.17= AutoProgress

/* Missing aggpri */
BV_Package_5.0 = 16
BV_Package_5.1 = SPName
BV_Package_5.2 = AggThresh
BV_Package_5.3 = Activate
BV_Package_5.4 = Deactivate
BV_Package_5.5 = Recycle
BV_Package_5.6 = Display
BV_Package_5.7 = Console
BV_Package_5.8 = UserData
BV_Package_5.9 = SpanName
BV_Package_5.10= DisplayStatus
BV_Package_5.11= Correlator
BV_Package_5.12= Unlink
BV_Package_5.13= Row
BV_Package_5.14= Column
BV_Package_5.15= Mark
BV_Package_5.16= AutoProgress

/* Cluster-ish stuff */
BV_Package_6.0 = 10
BV_Package_6.1 = AggThresh
BV_Package_6.2 = Console
BV_Package_6.3 = UserData
BV_Package_6.4 = DisplayStatus
BV_Package_6.5 = Correlator
BV_Package_6.6 = Unlink
BV_Package_6.7 = Row
BV_Package_6.8 = Column
BV_Package_6.9 = Mark
BV_Package_6.10= AutoProgress

/* Circuit-ish stuff */
BV_Package_7.0 = 11
BV_Package_7.1 = AggPri
BV_Package_7.2 = AggThresh
BV_Package_7.3 = Console
BV_Package_7.4 = UserData
BV_Package_7.5 = DisplayStatus
BV_Package_7.6 = Correlator
BV_Package_7.7 = Unlink
BV_Package_7.8 = Row
BV_Package_7.9 = Column
BV_Package_7.10= Mark
BV_Package_7.11= AutoProgress

/* System: Common - but no SPNAME */
BV_Package_8.0 = 15
BV_Package_8.1 = AggThresh
BV_Package_8.2 = Activate
BV_Package_8.3 = Deactivate
BV_Package_8.4 = Recycle
BV_Package_8.5 = Display
BV_Package_8.6 = Console
BV_Package_8.7 = UserData
BV_Package_8.8 = SpanName
BV_Package_8.9 = DisplayStatus
BV_Package_8.10= Correlator
BV_Package_8.11= Unlink
BV_Package_8.12= Row
BV_Package_8.13= Column
BV_Package_8.14= Mark
BV_Package_8.15= AutoProgress

/* SNA, MAJNODE stuff */
BV_Package_9.0 = 11
BV_Package_9.1 = SNADomain
BV_Package_9.2 = AggPri
BV_Package_9.3 = Console
BV_Package_9.4 = UserData
BV_Package_9.5 = DisplayStatus
BV_Package_9.6 = Correlator
BV_Package_9.7 = Unlink
BV_Package_9.8 = Row
BV_Package_9.9 = Column
BV_Package_9.10= Mark
BV_Package_9.11= AutoProgress

/* Special for GMFHS Managed Real */
BV_Package_10.0 = 20
BV_Package_10.1 = AggPri
BV_Package_10.2 = Activate
BV_Package_10.3 = Deactivate
BV_Package_10.4 = Display
BV_Package_10.5 = Console
BV_Package_10.6 = UserData
BV_Package_10.7 = SpanName
BV_Package_10.8 = OtherData
BV_Package_10.9 = DisplayStatus
BV_Package_10.10= DisplayName
BV_Package_10.11= NonSNADRT
BV_Package_10.12= QueryField
BV_Package_10.13= Domain
BV_Package_10.14= Correlator
BV_Package_10.15= Unlink
BV_Package_10.16= Row
BV_Package_10.17= Column
BV_Package_10.18= Mark
BV_Package_10.19= AutoProgress
BV_Package_10.20= Create

/* Special for GMFHS Aggregate */
BV_Package_11.0 = 14
BV_Package_11.1 = GMFHSAggType
BV_Package_11.2 = AggThresh
BV_Package_11.3 = Console
BV_Package_11.4 = UserData
BV_Package_11.5 = OtherData
BV_Package_11.6 = DisplayStatus
BV_Package_11.7 = DisplayName
BV_Package_11.8 = Correlator
BV_Package_11.9 = Unlink
BV_Package_11.10= Row
BV_Package_11.11= Column
BV_Package_11.12= Mark
BV_Package_11.13= AutoProgress
BV_Package_11.14= Create

/* APPN stuff */
BV_Package_12.0 = 10
BV_Package_12.1 = AggPri
BV_Package_12.2 = Console
BV_Package_12.3 = UserData
BV_Package_12.4 = DisplayStatus
BV_Package_12.5 = Correlator
BV_Package_12.6 = Unlink
BV_Package_12.7 = Row
BV_Package_12.8 = Column
BV_Package_12.9 = Mark
BV_Package_12.10= AutoProgress

/* OTHER special stuff */
BV_Package_13.0 = 17
BV_Package_13.1 = OtherClass
BV_Package_13.2 = AggPri
BV_Package_13.3 = AggThresh
BV_Package_13.4 = Activate
BV_Package_13.5 = Deactivate
BV_Package_13.6 = Recycle
BV_Package_13.7 = Display
BV_Package_13.8 = Console
BV_Package_13.9 = UserData
BV_Package_13.10= SpanName
BV_Package_13.11= DisplayStatus
BV_Package_13.12= Correlator
BV_Package_13.13= Unlink
BV_Package_13.14= Row
BV_Package_13.15= Column
BV_Package_13.16= Mark
BV_Package_13.17= AutoProgress

/* AGGCHILD special stuff */
BV_Package_14.0 = 10
BV_Package_14.1 = AggChildType
BV_Package_14.2 = DetailLink
BV_Package_14.3 = Segment
BV_Package_14.4 = ATMClusterQuietName
BV_Package_14.5 = QueryField
BV_Package_14.6 = System
BV_Package_14.7 = SNADomain
BV_Package_14.8 = Unlink
BV_Package_14.9 = AggChildClass
BV_Package_14.10= AggChildLink

BV_Package_15.0 = 16;
BV_Package_15.1 = SPName
BV_Package_15.2 = Segment
BV_Package_15.3 = AggPri
BV_Package_15.4 = Activate
BV_Package_15.5 = Deactivate
BV_Package_15.6 = Recycle
BV_Package_15.7 = Display
BV_Package_15.8 = Console
BV_Package_15.9 = UserData
BV_Package_15.10= DisplayStatus
BV_Package_15.11= Correlator
BV_Package_15.12= Unlink
BV_Package_15.13= Row
BV_Package_15.14= Column
BV_Package_15.15= Mark
BV_Package_15.16= AutoProgress

BV_Package_16.0 = 16
BV_Package_16.1 = SPName
BV_Package_16.2 = AggThresh
BV_Package_16.3 = Activate
BV_Package_16.4 = Deactivate
BV_Package_16.5 = Recycle
BV_Package_16.6 = Display
BV_Package_16.7 = Console
BV_Package_16.8 = UserData
BV_Package_16.9 = SpanName
BV_Package_16.10= DisplayStatus
BV_Package_16.11= Correlator
BV_Package_16.12= Unlink
BV_Package_16.13= Row
BV_Package_16.14= Column
BV_Package_16.15= Mark
BV_Package_16.16= AutoProgress

/* Missing aggpri, has ManNodeName - not used now that TME is gone */
BV_Package_17.0 = 17
BV_Package_17.1 = SPName
BV_Package_17.2 = ManNodeName
BV_Package_17.3 = AggThresh
BV_Package_17.4 = Activate
BV_Package_17.5 = Deactivate
BV_Package_17.6 = Recycle
BV_Package_17.7 = Display
BV_Package_17.8 = Console
BV_Package_17.9 = UserData
BV_Package_17.10= SpanName
BV_Package_17.11= DisplayStatus
BV_Package_17.12= Correlator
BV_Package_17.13= Unlink
BV_Package_17.14= Row
BV_Package_17.15= Column
BV_Package_17.16= Mark
BV_Package_17.17= AutoProgress

/* For ITNM/STM resources */
BV_Package_18.0 = 8
BV_Package_18.1 = AggThresh
BV_Package_18.2 = UserData
BV_Package_18.3 = SpanName
BV_Package_18.4 = DisplayStatus
BV_Package_18.5 = Correlator
BV_Package_18.6 = Unlink
BV_Package_18.7 = Mark
BV_Package_18.8 = AutoProgress

Return;


/*********************************************************************/
/*                                                                   */
/* GETCLASS                                                          */
/*                                                                   */
/* Retrieves the entire list of RODM classes and their OSI names.    */
/*                                                                   */
/* Requires that the ID you are running this from is authorized to   */
/* query RODM.                                                       */
/*                                                                   */
/* You may wish to invoke this exec with a command like like this:   */
/*                                                                   */
/* pipe netv getclass | > 'myhlq.myllq(member)' | console            */
/*                                                                   */
/* And when you get the output blurted to the screen, you can do a   */
/* PCOMM transfer of 'myhlq.myllq(member) to the workstation as      */
/* classnames.txt, and you're good to go!                            */
/*                                                                   */
/* WHO WHEN       WHAT                                               */
/* --- ---------- -------------------------------------------------- */
/* DLS 11/16/2000 Create                                             */
/* DLS 08/01/2001 Don't duplicate class names... they get longer than*/
/*                80 columns, confusing datasets                     */
/*                                                                   */
/*********************************************************************/
ADDRESS NETVASIS
'GLOBALV GETC CNMSTYLE.RODMNAME'
RODMName = CNMSTYLE.RODMNAME;
'pipe netv EKGVACTM 'RODMName' N-U-L-L N-U-L-L UCO *'
command = 'EKGVQUEM 'RODMName OPID()' 2 0 * 0 N-U-L-L 0 MyName 0 5000'
'pipe (stagesep | ) netv 'command' | stem fred.'
Do i = 1 to fred.0
  if (next = 1) Then
  Do
    rawName = fred.i;
    parse var rawName "'" className "'"
    /* If the class name starts with a numeric, go for its OSI name */
    if (datatype(substr(className,1,1),'N') = 1) Then
    Do
      'pipe (stagesep |) netv CNME2103 'className' | var george'
      parse var george crap '=' CNVOSIName crap
      if (CNVOSIName = '??') Then
        CNVOSIName = className;
    End
    Else
      CNVOSIName = className;
    if (ClassName = CNVOSIName) Then
      ClassName = "*"
    Say ClassName','CNVOSIName
  End
  if (strip(fred.i) = 'MyName (SHORTNAME)') Then
    next = 1;
  else
    next = 0;
End
'pipe netv EKGVACTM 'RODMName' N-U-L-L N-U-L-L DISC'
